bayespy.inference.vmp.nodes.gaussian_markov_chain.GaussianMarkovChainDistribution
=================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian_markov_chain

.. autoclass:: GaussianMarkovChainDistribution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianMarkovChainDistribution.__init__
      ~GaussianMarkovChainDistribution.compute_cgf_from_parents
      ~GaussianMarkovChainDistribution.compute_fixed_moments_and_f
      ~GaussianMarkovChainDistribution.compute_gradient
      ~GaussianMarkovChainDistribution.compute_logpdf
      ~GaussianMarkovChainDistribution.compute_mask_to_parent
      ~GaussianMarkovChainDistribution.compute_message_to_parent
      ~GaussianMarkovChainDistribution.compute_moments_and_cgf
      ~GaussianMarkovChainDistribution.compute_phi_from_parents
      ~GaussianMarkovChainDistribution.plates_from_parent
      ~GaussianMarkovChainDistribution.plates_to_parent
      ~GaussianMarkovChainDistribution.random
   
   

   
   
   